/*
	File:		som_SamplePart.cpp

	Contains:	Sample Part's SOM based part public interface implementation

	Written by:	Steve Smith
	
	Copyright:	 1995 by Apple Computer, Inc., all rights reserved.
	
	----------------------------------------------------------------
	
	Notes:		SamplePart is implemented using a "wrapped" class strategy.
				This means that the SOM class is just a smart delegator and
				the real implementation lives in a C++ class. The reason for
				doing this is twofold. First, this strategy all but elimintates
				the need for you to have to modify the IDL file and run the
				SOM compiler/emitter. Secondly, given that all code changes
				will occur in the C++ class, build turn around time is reduced
				to however fast the compiler can crunch code.
				
				This is not to say that implementing pure SOM classes isn't
				possible, nor necessary. There will be objects (ie. Extensions)
				which need to be exported for other parts to use which will need
				to be written in IDL and SOM implementation files.
*/

// Notification that this is a SOM source file
#define SampleCode_som_SamplePart_Class_Source

// define underscore field names (ie. _fSelf)
#define VARIABLE_MACROS

// -- Compiler/Preprocessor Switches --

#ifndef _COMPILERDEFS_
#include "CompDefs.h"
#endif

// -- OpenDoc Utilities --

#ifndef _EXCEPT_
// Exceptions define several important macros (ie. CHECKENV)
// which are used in the SOM method dispatch glue. If Except.h
// is not included early enough, exceptions may not be thrown
// correctly when returning from a SOM method with the "ev" parameter set.
#include <Except.h>
#endif

// -- SamplePart Includes --

#ifndef SOM_SampleCode_som_SamplePart_xih
#include "som_SamplePart.xih"
#endif

#ifndef _SAMPLEPART_
#include "SamplePart.h"
#endif

#ifndef _SAMPLEPARTDEF_
#include "SamplePartDef.h"
#endif

// -- OpenDoc Includes --

#ifndef _ODTYPES_
#include <ODTypes.h>
#endif

#ifndef SOM_ODPart_xh
#include <Part.xh>
#endif

#pragma segment somSamplePart

//====================================================================
// som_SamplePart
//====================================================================

SOM_Scope void  SOMLINK som_SamplePart__somInit(SampleCode_som_SamplePart *somSelf)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__somInit");

	// somInit and somUninit methods behave like C++ constructors in that the
	// inherited methods are called automatically. Thus, there is no need to
	// call the parent class' somInit or somUninit.
	
	// There is also no need to set instance variables to zero/NULL
	// since SOM guarantees that a newly constructed object is zeroed.
	
	// Lastly, it is not valid to perform any operation here which may throw
	// an exception.
}

SOM_Scope void  SOMLINK som_SamplePart__somUninit(SampleCode_som_SamplePart *somSelf)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__somUninit");

	delete _fPart;
}

SOM_Scope void  SOMLINK som_SamplePart__InitPart(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODStorageUnit* storageUnit,
		ODPart* partWrapper)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__InitPart");

	SOM_TRY
		// Create the real C++ SamplePart.		
		_fPart = new SamplePart;

		SampleCode_som_SamplePart_parent_ODPart_InitPart(somSelf,ev,storageUnit,partWrapper);
		_fPart->InitPart(ev,storageUnit,partWrapper);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__InitPartFromStorage(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODStorageUnit* storageUnit,
		ODPart* partWrapper)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__InitPartFromStorage");

	SOM_TRY
		// Create the real C++ SamplePart.		
		_fPart = new SamplePart;

		SampleCode_som_SamplePart_parent_ODPart_InitPartFromStorage(somSelf,ev,storageUnit,partWrapper);
		_fPart->InitPartFromStorage(ev,storageUnit,partWrapper);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__Externalize(SampleCode_som_SamplePart *somSelf, Environment *ev)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__Externalize");

	SOM_TRY
		SampleCode_som_SamplePart_parent_ODPart_Externalize(somSelf,ev);
		_fPart->Externalize(ev);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope ODSize  SOMLINK som_SamplePart__Purge(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODSize size)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__Purge");

	ODSize result;

	SOM_TRY
		result = _fPart->Purge(ev,size);
	SOM_CATCH_ALL
		result = 0;
	SOM_ENDTRY
	
	return result;
}

SOM_Scope void  SOMLINK som_SamplePart__Release(SampleCode_som_SamplePart *somSelf, Environment *ev)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__Release");

	SOM_TRY
		SampleCode_som_SamplePart_parent_ODPart_Release(somSelf,ev);
		_fPart->Release(ev);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__ReleaseAll(SampleCode_som_SamplePart *somSelf, Environment *ev)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__ReleaseAll");

	SOM_TRY
		_fPart->ReleaseAll(ev);
		SampleCode_som_SamplePart_parent_ODPart_ReleaseAll(somSelf,ev);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope ODExtension*  SOMLINK som_SamplePart__AcquireExtension(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODType extensionName)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__GetExtension");

	ODExtension* result;

	SOM_TRY
		// We don't support any extensions, but one of our parent classes might;
		result = SampleCode_som_SamplePart_parent_ODPart_AcquireExtension(somSelf,ev,extensionName);
	SOM_CATCH_ALL
		result = kODNULL;
	SOM_ENDTRY

	return result;
}

SOM_Scope ODBoolean  SOMLINK som_SamplePart__HasExtension(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODType extensionName)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__HasExtension");

	ODBoolean result;

	SOM_TRY
		// We don't support any extensions, but one of our parent classes might;
		result = SampleCode_som_SamplePart_parent_ODPart_HasExtension(somSelf,ev,extensionName);
	SOM_CATCH_ALL
		result = kODFalse;
	SOM_ENDTRY

	return result;
}

SOM_Scope void  SOMLINK som_SamplePart__ReleaseExtension(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODExtension* extension)
{
    SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__ReleaseExtension");

	SOM_TRY
		// We don't support any extensions, but one of our parent classes might;
	    SampleCode_som_SamplePart_parent_ODPart_ReleaseExtension(somSelf,ev,extension);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__FulfillPromise(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODStorageUnitView* /*promiseSUView*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__FulfillPromise");
}

SOM_Scope void  SOMLINK som_SamplePart__DropCompleted(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODPart* ,
		ODDropResult dropResult)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__DropCompleted");
}

SOM_Scope ODDragResult  SOMLINK som_SamplePart__DragEnter(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODDragItemIterator* /*dragInfo*/,
		ODFacet* /*facet*/,
		ODPoint* /*where*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__DragEnter");

	return kODFalse;
}

SOM_Scope ODDragResult  SOMLINK som_SamplePart__DragWithin(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODDragItemIterator* /*dragInfo*/,
		ODFacet* /*facet*/,
		ODPoint* /*where*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__DragWithin");

	return kODFalse;
}

SOM_Scope void  SOMLINK som_SamplePart__DragLeave(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFacet* /*facet*/,
		ODPoint* /*where*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__DragLeave");
}

SOM_Scope ODDropResult  SOMLINK som_SamplePart__Drop(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODDragItemIterator* /*dropInfo*/,
		ODFacet* /*facet*/,
		ODPoint* /*where*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__Drop");

	return kODDropFail;
}

SOM_Scope ODBoolean  SOMLINK som_SamplePart__RevealFrame(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* /*embeddedFrame*/,
		ODShape* /*revealShape*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__RevealFrame");

	return kODFalse;
}

SOM_Scope ODBoolean  SOMLINK som_SamplePart__EditInLinkAttempted(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame)
{
    SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__EditInLinkAttempted");

    return kODFalse;
}

SOM_Scope void  SOMLINK som_SamplePart__EmbeddedFrameUpdated(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame,
		ODUpdateID change)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__EmbeddedFrameChanged");
}

SOM_Scope void  SOMLINK som_SamplePart__EmbeddedFrameSpec(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* /*embeddedFrame*/,
		ODObjectSpec* /*spec*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__EmbeddedFrameSpec");
}

SOM_Scope void  SOMLINK som_SamplePart__ContainingPartPropertiesUpdated(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame,
		ODStorageUnit* propertyUnit)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__ContainingPartPropertiesChanged");
}

SOM_Scope void  SOMLINK som_SamplePart__DisplayFrameAdded(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__DisplayFrameAdded");

	SOM_TRY
		_fPart->DisplayFrameAdded(ev,frame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__DisplayFrameRemoved(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__DisplayFrameRemoved");

	SOM_TRY
		_fPart->DisplayFrameRemoved(ev,frame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__DisplayFrameConnected(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__DisplayFrameConnected");

	SOM_TRY
		_fPart->DisplayFrameConnected(ev,frame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__DisplayFrameClosed(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__DisplayFrameClosed");

	SOM_TRY
		_fPart->DisplayFrameClosed(ev,frame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__AttachSourceFrame(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame,
		ODFrame* sourceFrame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__AttachSourceFrame");

	SOM_TRY
		_fPart->AttachSourceFrame(ev,frame,sourceFrame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__FrameShapeChanged(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__FrameShapeChanged");

	SOM_TRY
		_fPart->FrameShapeChanged(ev,frame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__ViewTypeChanged(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__ViewTypeChanged");

	SOM_TRY
		_fPart->ViewTypeChanged(ev,frame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__PresentationChanged(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* /*frame*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__PresentationChanged");
}

SOM_Scope void  SOMLINK som_SamplePart__SequenceChanged(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* /*frame*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__SequenceChanged");
}

SOM_Scope void  SOMLINK som_SamplePart__ClonePartInfo(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODDraftKey key,
		ODInfoType partInfo,
		ODStorageUnitView* storageUnitView,
		ODFrame* scopeFrame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__ClonePartInfo");

	SOM_TRY
		_fPart->ClonePartInfo(ev,key,partInfo,storageUnitView,scopeFrame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__WritePartInfo(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODInfoType partInfo,
		ODStorageUnitView* storageUnitView)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__WritePartInfo");

	SOM_TRY
		_fPart->WritePartInfo(ev,partInfo,storageUnitView);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope ODInfoType  SOMLINK som_SamplePart__ReadPartInfo(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame,
		ODStorageUnitView* storageUnitView)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__ReadPartInfo");

	ODInfoType result;

	SOM_TRY
		result = _fPart->ReadPartInfo(ev,frame,storageUnitView);
	SOM_CATCH_ALL
		result = kODNULL;
	SOM_ENDTRY

	return result;
}

SOM_Scope ODID  SOMLINK som_SamplePart__Open(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__Open");

	ODID result;

	SOM_TRY
		result = _fPart->Open(ev,frame);
	SOM_CATCH_ALL
		result = kODNULLID;
	SOM_ENDTRY

	return result;
}

SOM_Scope ODFrame*  SOMLINK som_SamplePart__RequestEmbeddedFrame(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* containingFrame,
		ODFrame* baseFrame,
		ODShape* frameShape,
		ODPart* embeddedPart,
		ODTypeToken viewType,
		ODTypeToken presentation,
		ODBoolean isOverlaid)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__RequestEmbeddedFrame");

	return kODNULL;
}

SOM_Scope void  SOMLINK som_SamplePart__RemoveEmbeddedFrame(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* /*embeddedFrame*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__RemoveEmbeddedFrame");
}

SOM_Scope ODShape*  SOMLINK som_SamplePart__RequestFrameShape(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* /*embeddedFrame*/,
		ODShape* /*frameShape*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__RequestFrameShape");

	return kODNULL;
}

SOM_Scope void  SOMLINK som_SamplePart__UsedShapeChanged(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* /*embeddedFrame*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__UsedShapeChanged");
}

SOM_Scope ODStorageUnit*  SOMLINK som_SamplePart__AcquireContainingPartProperties(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__GetContainingPartProperties");

	return kODNULL;
}

SOM_Scope ODShape*  SOMLINK som_SamplePart__AdjustBorderShape(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFacet* /*embeddedFacet*/,
		ODShape* /*shape*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__AdjustBorderShape");

	return kODNULL;
}

SOM_Scope void  SOMLINK som_SamplePart__FacetAdded(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFacet* facet)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__FacetAdded");

	SOM_TRY
		_fPart->FacetAdded(ev,facet);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__FacetRemoved(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFacet* facet)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__FacetRemoved");

	SOM_TRY
		_fPart->FacetRemoved(ev,facet);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__CanvasChanged(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFacet* /*facet*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__CanvasChanged");
}

SOM_Scope void  SOMLINK som_SamplePart__GeometryChanged(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFacet* facet,
		ODBoolean clipShapeChanged,
		ODBoolean externalTransformChanged)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__GeometryChanged");

	SOM_TRY
		_fPart->GeometryChanged(ev,facet,clipShapeChanged,externalTransformChanged);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__Draw(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFacet* facet,
		ODShape* invalidShape)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__Draw");

	SOM_TRY
		_fPart->Draw(ev,facet,invalidShape);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__CanvasUpdated(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODCanvas* /*canvas*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__CanvasUpdated");
}

SOM_Scope void  SOMLINK som_SamplePart__HighlightChanged(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFacet* facet)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__HighlightChanged");

	SOM_TRY
		_fPart->HighlightChanged(ev,facet);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope ODULong  SOMLINK som_SamplePart__GetPrintResolution(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* /*frame*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__GetPrintResolution");

	return kMinImagingResolution;
}

SOM_Scope ODLinkSource*  SOMLINK som_SamplePart__CreateLink(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODByteArray* /*data*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__CreateLink");

	return kODNULL;
}

SOM_Scope void  SOMLINK som_SamplePart__LinkUpdated(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODLink* link,
		ODUpdateID change)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__LinkUpdated");
}

SOM_Scope void  SOMLINK som_SamplePart__RevealLink(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODLinkSource* /*linkSource*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__RevealLink");
}

SOM_Scope void  SOMLINK som_SamplePart__LinkStatusChanged(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* /*frame*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__LinkStatusChanged");
}

SOM_Scope ODBoolean  SOMLINK som_SamplePart__BeginRelinquishFocus(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODTypeToken focus,
		ODFrame* ownerFrame,
		ODFrame* proposedFrame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__BeginRelinquishFocus");

	ODBoolean result;

	SOM_TRY
		result = _fPart->BeginRelinquishFocus(ev,focus,ownerFrame,proposedFrame);
	SOM_CATCH_ALL
		result = kODFalse;
	SOM_ENDTRY

	return result;
}

SOM_Scope void  SOMLINK som_SamplePart__CommitRelinquishFocus(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODTypeToken focus,
		ODFrame* ownerFrame,
		ODFrame* proposedFrame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__CommitRelinquishFocus");

	SOM_TRY
		_fPart->CommitRelinquishFocus(ev,focus,ownerFrame,proposedFrame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__AbortRelinquishFocus(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODTypeToken focus,
		ODFrame* ownerFrame,
		ODFrame* proposedFrame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__AbortRelinquishFocus");

	SOM_TRY
		_fPart->AbortRelinquishFocus(ev,focus,ownerFrame,proposedFrame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__FocusAcquired(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODTypeToken focus,
		ODFrame* ownerFrame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__FocusAcquired");

	SOM_TRY
		_fPart->FocusAcquired(ev,focus,ownerFrame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__FocusLost(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODTypeToken focus,
		ODFrame* ownerFrame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__FocusLost");

	SOM_TRY
		_fPart->FocusLost(ev,focus,ownerFrame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__CloneInto(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODDraftKey key,
		ODStorageUnit* toSU,
		ODFrame* scope)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__CloneInto");

	SOM_TRY
		SampleCode_som_SamplePart_parent_ODPart_CloneInto(somSelf,ev,key,toSU,scope);
		_fPart->CloneInto(ev,key,toSU,scope);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__ExternalizeKinds(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODTypeList* kindset)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__ExternalizeKinds");

	SOM_TRY
		_fPart->ExternalizeKinds(ev,kindset);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__ChangeKind(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODType kind)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__ChangeKind");

	SOM_TRY
		_fPart->ChangeKind(ev,kind);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope ODBoolean  SOMLINK som_SamplePart__HandleEvent(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODEventData* event,
		ODFrame* frame,
		ODFacet* facet,
		ODEventInfo* eventInfo)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__HandleEvent");

	ODBoolean result;

	SOM_TRY
		result = _fPart->HandleEvent(ev,event,frame,facet,eventInfo);
	SOM_CATCH_ALL
		result = kODFalse;
	SOM_ENDTRY

	return result;
}

SOM_Scope void  SOMLINK som_SamplePart__AdjustMenus(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODFrame* frame)
{
	SampleCode_som_SamplePartData *somThis = SampleCode_som_SamplePartGetData(somSelf);
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__AdjustMenus");

	SOM_TRY
		_fPart->AdjustMenus(ev,frame);
	SOM_CATCH_ALL
	SOM_ENDTRY
}

SOM_Scope void  SOMLINK som_SamplePart__UndoAction(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODActionData* /*actionState*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__UndoAction");
}

SOM_Scope void  SOMLINK som_SamplePart__RedoAction(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODActionData* /*actionState*/)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__RedoAction");
}

SOM_Scope void  SOMLINK som_SamplePart__DisposeActionState(SampleCode_som_SamplePart *somSelf, Environment *ev,
		ODActionData* ,
		ODDoneState doneState)
{
	SampleCode_som_SamplePartMethodDebug("SampleCode_som_SamplePart","som_SamplePart__DisposeActionState");
}
